@@ -8,9 +8,9 @@
     require DBI::Gofer::Response;
     require Carp;
 
-    our $VERSION = sprintf("0.%06d", q$Revision: 11377 $ =~ /(\d+)/o);
+    our $VERSION = sprintf("0.%06d", q$Revision: 14282 $ =~ /(\d+)/o);
 
-#   $Id: Gofer.pm 11377 2008-06-03 22:18:04Z timbo $
+#   $Id: Gofer.pm 14282 2010-07-26 00:12:54Z theory $
 #
 #   Copyright (c) 2007, Tim Bunce, Ireland
 #
@@ -29,6 +29,7 @@
         FetchHashKeyName
         HandleError HandleSetErr
         InactiveDestroy
+        AutoInactiveDestroy
         PrintError PrintWarn
         Profile
         RaiseError
@@ -46,7 +47,7 @@
         dbi_connect_method
     );
 
-    our $drh = undef;    # holds driver handle once initialised
+    our $drh = undef;    # holds driver handle once initialized
     our $methods_already_installed;
 
     sub driver{
@@ -91,11 +92,12 @@
 
 
     sub set_err_from_response { # set error/warn/info and propagate warnings
-        my ($h, $response) = @_;
+        my $h = shift;
+        my $response = shift;
         if (my $warnings = $response->warnings) {
             warn $_ for @$warnings;
         }
-        return $h->set_err($response->err, $response->errstr, $response->state);
+        return $h->set_err($response->err_errstr_state);
     }
 
 
@@ -301,7 +303,7 @@
 
         if (my $dbh_attributes = $response->dbh_attributes) {
 
-            # XXX installed_methods piggbacks on dbh_attributes for now
+            # XXX installed_methods piggybacks on dbh_attributes for now
             if (my $installed_methods = delete $dbh_attributes->{dbi_installed_methods}) {
                 DBD::Gofer::install_methods_proxy($installed_methods)
                     if $dbh->{go_request_count}==1;
@@ -834,7 +836,7 @@ transport module being used.
 =head1 DESCRIPTION
 
 DBD::Gofer is a DBI database driver that forwards requests to another DBI
-driver, usually in a seperate process, often on a separate machine. It tries to
+driver, usually in a separate process, often on a separate machine. It tries to
 be as transparent as possible so it appears that you are using the remote
 driver directly.
 
@@ -914,7 +916,7 @@ They can be set after connect() but the change is only applied locally.
 
 =head2 You can't change statement handle attributes after prepare()
 
-You can't change statment handle attributes after prepare.
+You can't change statement handle attributes after prepare.
 
 An exception is made for attributes with names starting "C<private_>":
 They can be set after prepare() but the change is only applied locally.
@@ -1060,7 +1062,7 @@ driver.
 
 The stream driver also launches a subprocess and writes requests and reads
 responses, like the pipeone transport.  In this case, however, the subprocess
-is expected to handle more that one request. (Though it will be automitically
+is expected to handle more that one request. (Though it will be automatically
 restarted if it exits.)
 
 This is the first transport that is truly useful because it can launch the
@@ -1182,7 +1184,7 @@ $request->is_idempotent is true (i.e., the dbh has the ReadOnly attribute set
 or the SQL statement is obviously a SELECT without a FOR UPDATE clause.)
 
 For even more control you can use the C<go_cache> attribute to pass in an
-instanciated cache object. Individual methods, including prepare(), can also
+instantiated cache object. Individual methods, including prepare(), can also
 specify alternative caches via the C<go_cache> attribute. For example, to
 specify no caching for a particular query, you could use
 
@@ -1246,7 +1248,7 @@ L<DBI>
 
 This section aims to record issues to be aware of when using Gofer with specific drivers.
 It usually only documents issues that are not natural consequences of the limitations
-of the Gofer approach - as documented avove.
+of the Gofer approach - as documented above.
 
 =head1 TODO
 
@@ -1269,7 +1271,7 @@ in such a way that appropriate http cache headers are added to the results
 so that web caches (squid etc) could be used to implement the caching.
 (MUST require the use of GET rather than POST requests.)
 
-Rework handling of installed_methods to not piggback on dbh_attributes?
+Rework handling of installed_methods to not piggyback on dbh_attributes?
 
 Perhaps support transactions for transports where it's possible (ie null and stream)?
 Would make stream transport (ie ssh) more useful to more people.
