@@ -5,10 +5,10 @@
     require Carp;
 
     our @EXPORT = qw(); # Do NOT @EXPORT anything.
-    our $VERSION = sprintf("12.%06d", q$Revision: 8696 $ =~ /(\d+)/o);
+    our $VERSION = sprintf("12.%06d", q$Revision: 10002 $ =~ /(\d+)/o);
 
 
-#   $Id: Sponge.pm 8696 2007-01-24 23:12:38Z timbo $
+#   $Id: Sponge.pm 10002 2007-09-26 21:03:25Z timbo $
 #
 #   Copyright (c) 1994-2003 Tim Bunce Ireland
 #
@@ -53,7 +53,7 @@
     sub prepare {
 	my($dbh, $statement, $attribs) = @_;
 	my $rows = delete $attribs->{'rows'}
-	    or return $dbh->set_err(1,"No rows attribute supplied to prepare");
+	    or return $dbh->set_err($DBI::stderr,"No rows attribute supplied to prepare");
 	my ($outer, $sth) = DBI::_new_sth($dbh, {
 	    'Statement'   => $statement,
 	    'rows'        => $rows,
@@ -69,7 +69,7 @@
 	if ($statement =~ /^\s*insert\b/) {	# very basic, just for testing execute_array()
 	    $sth->{is_insert} = 1;
 	    my $NUM_OF_PARAMS = $attribs->{NUM_OF_PARAMS}
-		or return $dbh->set_err(1,"NUM_OF_PARAMS not specified for INSERT statement");
+		or return $dbh->set_err($DBI::stderr,"NUM_OF_PARAMS not specified for INSERT statement");
 	    $sth->STORE('NUM_OF_PARAMS' => $attribs->{NUM_OF_PARAMS} );
 	}
 	else {	#assume select
@@ -85,7 +85,7 @@
 	    } elsif (my $firstrow = $rows->[0]) {
 		$numFields = scalar @$firstrow;
 	    } else {
-		return $dbh->set_err(1, 'Cannot determine NUM_OF_FIELDS');
+		return $dbh->set_err($DBI::stderr, 'Cannot determine NUM_OF_FIELDS');
 	    }
 	    $sth->STORE('NUM_OF_FIELDS' => $numFields);
 	    $sth->{NAME} = $attribs->{NAME}
@@ -174,7 +174,7 @@
 	    my $row;
 	    $row = (@_) ? [ @_ ] : die "bind_param not supported yet" ;
 	    my $NUM_OF_PARAMS = $sth->{NUM_OF_PARAMS};
-	    return $sth->set_err(1, @$row." values bound (@$row) but $NUM_OF_PARAMS expected")
+	    return $sth->set_err($DBI::stderr, @$row." values bound (@$row) but $NUM_OF_PARAMS expected")
 		if @$row != $NUM_OF_PARAMS;
 	    { local $^W; $sth->trace_msg("inserting (@$row)\n"); }
 	    push @{ $sth->{rows} }, $row;
