@@ -1,5 +1,5 @@
 ###
-### $Id: FAQ.pm 9530 2007-05-09 13:05:23Z timbo $
+### $Id: FAQ.pm 14270 2010-07-22 17:22:06Z timbo $
 ###
 ### DBI Frequently Asked Questions POD
 ###
@@ -21,7 +21,7 @@
 
 package DBI::FAQ;
 
-our $VERSION = sprintf("1.%06d", q$Revision: 9530 $ =~ /(\d+)/o);
+our $VERSION = sprintf("1.%06d", q$Revision: 14270 $ =~ /(\d+)/o);
 
 
 =head1 NAME
@@ -50,6 +50,8 @@ DBI Frequently Asked Questions v.0.38
 
 This document is currently at version I<0.38>, as of I<February 8th, 2000>.
 
+That's B<very> old. A newer FAQ can be found at L<http://faq.dbi-support.com/>
+
 =head1 DESCRIPTION
 
 This document serves to answer the most frequently asked questions on both
@@ -61,10 +63,10 @@ the DBI Mailing Lists and personally to members of the DBI development team.
 
 To quote Tim Bunce, the architect and author of DBI:
 
-    ``DBI is a database access Application Programming Interface (API)
+      DBI is a database access Application Programming Interface (API)
       for the Perl Language. The DBI API Specification defines a set
       of functions, variables and conventions that provide a consistent
-      database interface independant of the actual database being used.''
+      database interface independent of the actual database being used.
 
 In simple language, the DBI interface allows users to access multiple database
 types transparently. So, if you connecting to an Oracle, Informix, mSQL, Sybase
@@ -562,22 +564,21 @@ should using the most recent I<DBD::Oracle> version.
 
 Yes, use the I<DBD::ODBC> driver.
 
-=head2 3.5 Is the a DBD for <I<insert favourite database here>>?
+=head2 3.5 Is there a DBD for <I<insert favourite database here>>?
 
-Is is listed on the DBI drivers page?
+First check if a driver is available on CPAN by searching for the name of the
+database (including common abbreviations and aliases).
 
-    http://dbi.perl.org/
-    http://www.symbolstone.org/technology/perl/DBI
+Here's a general query that'll match all distributions:
 
-If not, no. A complete absence of a given database driver from that
-page means that no-one has announced any intention to work on it, not that
-such a driver is impossible to write.
+    http://search.cpan.org/search?query=DBD&mode=dist
 
-A corollary of the above statement implies that if you see an announcement
-for a driver I<not> on the above page, there's a good chance it's not
-actually a I<DBI> driver, and may not conform to the specifications. Therefore,
-questions concerning problems with that code should I<not> really be addressed
-to the DBI Mailing Lists.
+If you can't find a driver that way, you could check if the database supports
+ODBC drivers. If so then you could probably use the DBD::ODBC driver:
+
+    http://search.cpan.org/dist/DBD-ODBC/
+
+If not, then try asking on the dbi-users mailing list.
 
 =head2 3.6 What's DBM? And why should I use DBI instead?
 
